@@ -12,7 +12,8 @@ use File::Copy             qw(copy);
 use Storable               qw(retrieve);
 use Template;
 use File::Slurp;
-use Text::Diff;
+use Text::Diff qw(diff);
+use Text::Patch qw(patch);
 use Win32;
 use Win32::File::Object;
 use IPC::Run3;
@@ -288,11 +289,11 @@ sub backup_file {
 
 sub _patch_file {
   my ($self, $new, $dst, $dir, $tt_vars, $no_backup) = @_;
-$self->boss->message(5, "PATCHING '$new' '$dst' '$dir' $tt_vars " . ($no_backup||'') . "\n");
+  $self->boss->message(5, "PATCHING '$new' '$dst' '$dir' $tt_vars " . ($no_backup||'') . "\n");
 
-if ($dst =~ /\*$/) {
+  if ($dst =~ /\*$/) {
     warn "WE ARE PATCHIN '$new'";
-}
+  }
   if ($new eq 'config_H.gc' and ref($dst) =~ /HASH/) {
     $self->boss->message(5, "_patch_file: using hash of values to update config_H.gc'\n");
     $self->_update_config_H_gc ("$dir/win32/config_H.gc", $dst);
@@ -436,12 +437,18 @@ sub _install_module {
   my $dumper_file = catfile($self->global->{debug_dir}, "mod_install_${shortname}_${now}.list.dumper.txt");
   my $nstore_file = catfile($self->global->{debug_dir}, "mod_install_${shortname}_${now}.list.nstore.txt");
 
-  my $env = {
-    PERL_MM_USE_DEFAULT=>1, AUTOMATED_TESTING=>undef, RELEASE_TESTING=>undef,
-    PERL5_CPANPLUS_HOME=>$self->global->{build_ENV}->{APPDATA}, #workaround for CPANPLUS
-    PERL_CPANM_HOME => ($self->global->{build_ENV}->{APPDATA} . '/.cpanm'), # GH#101
-    PKG_CONFIG_PATH => ($self->global->{image_dir} . '/c/lib/pkgconf'),  #  just to be sure
-  };
+  # if we're building with MSVC, we can't clobber the environment. ugh.
+  my $env = {};
+  if ($self->global->{maketool} eq 'nmake') {
+    $env = {%ENV};
+  }
+  $env->{PERL_MM_USE_DEFAULT} = 1;
+  $env->{AUTOMATED_TESTING} = undef;
+  $env->{RELEASE_TESTING} = undef;
+  $env->{PERL5_CPANPLUS_HOME} = $self->global->{build_ENV}->{APPDATA}; # workaround for CPANPLUS
+  $env->{PERL_CPANM_HOME} = ($self->global->{build_ENV}->{APPDATA} . '/.cpanm'); # GH#101
+  $env->{PKG_CONFIG_PATH} = ($self->global->{image_dir} . '/c/lib/pkgconf'); # just to be sure
+
   # resolve macros in env{}
   if (defined $args{env} && ref $args{env} eq 'HASH') {
     for my $var (keys %{$args{env}}) {
